package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!4``#0```!0@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````F'P`
M`)A\```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````8!`````````#``<```````"``0```````P`1``P`````
M`````````!(```#:`0`````````````2````%```````````````$0`````"
M`````````````!$```!\`0`````````````2````&P``````````````$@``
M`+D!`````````````!(````C```````````````2````*@``````````````
M$@````T"`````````````!(```#%`0`````````````2````,P``````````
M````(````$X#`````````````"$```!+```````````````2````40``````
M````````$@```%@``````````````!(````;`P`````````````2````#`,`
M````````````$@```)("`````````````!(```!?```````````````2````
M,P(`````````````$@```&8``````````````!(```#'`@`````````````2
M````;0``````````````$@```'4``````````````!(```"P`@``````````
M```2````?0``````````````$@```(,``````````````!(```",````````
M```````@````!0,`````````````$@```*@``````````````!(```"M````
M```````````2````'@(`````````````$0```,X"`````````````!(```!@
M`@`````````````2````M```````````````$@```%("`````````````!(`
M``!R`P`````````````2````V0(`````````````$0```$T#````````````
M`!$```"$`@`````````````2````.@,`````````````$@```$\#````````
M`````!$```"[```````````````2````,@,`````````````$@```,0`````
M`````````!$```"*`0`````````````2````U@``````````````(@```.4`
M`````````````"````#[```````````````2````_0(`````````````$@``
M`'`"`````````````!(``````0`````````````2````!@$`````````````
M(````+L"`````````````!(````@`0`````````````2````J@$`````````
M````$@```"4!`````````````!(```"@`@`````````````2````F0$`````
M````````$@```"L!`````````````!(````\`0`````````````2````+@(`
M````````````$@```'X``````````````!(````_`@`````````````2````
M>0(`````````````$@```"L#`````````````!(```!"`0`````````````2
M````(P,`````````````$@```%8!`````````````!(````I`@``````````
M```2````Z`$`````````````$@```%T!`````````````!(```!D`0``````
M```````2````3`,`````````````(0```'4!`````````````!(```!R!```
M;)`!```````0`!(`1P,``&@3``!P`@``$@`)`/H!``!`/P``!````!(`"@"T
M`P``:"8``,P&```2``D`@@0``,0P``!8````$@`)`)$#``"L'P``!````!(`
M"0`F!```8!````0````2``<`UP,``#0M``"0`P``$@`)`"P$```\@`$`````
M`!``$@!:!```L!\``"P"```2``D`#P0``#R``0``````$``2`*(#``"T)0``
MM````!(`"0#!`P``E!T``%P````2``D`R0,``#0E``!H````$@`)`.T#``#$
M/```1`$``!(`"0`"!```W"$``!P````2``D`&P0``&R0`0``````$``2`'T$
M``!LD`$``````!``$@!7`P``_!4``&0````2``D`.@0``/@A```(`0``$@`)
M`/@#```X@`$`!````!$`$0!3!```/(`!```````0`!$`%`0``-@5````````
M$@`)`",$``!T/```4````!(`"0!@`P``G"4``!@````2``D`>P,``%P>``!0
M`0``$@`)`&<$```(/@``.`$``!(`"0!Q!```;)`!```````0`!(`1@0````C
M```T`@``$@`)``!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``
M;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P
M96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N
M;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UA
M<FUH9BYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D
M:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?
M7U]E;G9I<F]N`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?
M8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P
M87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`P'T!`!<```#$
M?0$`%P```+Q_`0`7````R'\!`!<```#4?P$`%P````"``0`7````"(`!`!<`
M```,@`$`%P```!2``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!
M`!<````L@`$`%P```#"``0`7````.(`!`!<```#`?P$`%04``,1_`0`5!@``
MS'\!`!4.``#0?P$`%1\``-A_`0`5(P``W'\!`!4I``#@?P$`%2T``.1_`0`5
M,```Z'\!`!4R``#L?P$`%3,``/!_`0`5.```]'\!`!4]``#X?P$`%3X``/Q_
M`0`50P``Q'X!`!8#``#(?@$`%@0``,Q^`0`6!P``T'X!`!8(``#4?@$`%@D`
M`-A^`0`6"@``W'X!`!8+``#@?@$`%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`
M%A```/!^`0`6$0``]'X!`!82``#X?@$`%A,``/Q^`0`6%````'\!`!85```$
M?P$`%A8```A_`0`6%P``#'\!`!88```0?P$`%AD``!1_`0`6&@``&'\!`!8;
M```<?P$`%AP``"!_`0`6'0``)'\!`!8>```H?P$`%B```"Q_`0`6(0``,'\!
M`!8B```T?P$`%B0``#A_`0`6)0``/'\!`!8F``!`?P$`%B<``$1_`0`6*```
M2'\!`!8K``!,?P$`%BP``%!_`0`6+@``5'\!`!8O``!8?P$`%C$``%Q_`0`6
M,@``8'\!`!8S``!D?P$`%C0``&A_`0`6-0``;'\!`!8V``!P?P$`%C<``'1_
M`0`6.0``>'\!`!8Z``!\?P$`%CL``(!_`0`6/```A'\!`!8_``"(?P$`%D``
M`(Q_`0`600``D'\!`!9"``"4?P$`%D0``)A_`0`610``G'\!`!9&``"@?P$`
M%D<``*1_`0`62```J'\!`!9)``"L?P$`%DH``+!_`0`62P``M'\!`!9,``"X
M?P$`%DX```%`+>D!0+WH'O\OX03@+>4$X)_E#N"/X`CPON4\;@$``,:/XA;*
MC.(\_KSE`,:/XA;*C.(T_KSE`,:/XA;*C.(L_KSE`,:/XA;*C.(D_KSE`,:/
MXA;*C.(<_KSE`,:/XA;*C.(4_KSE`,:/XA;*C.(,_KSE`,:/XA;*C.($_KSE
M`,:/XA;*C.+\_;SE`,:/XA;*C.+T_;SE`,:/XA;*C.+L_;SE`,:/XA;*C.+D
M_;SE`,:/XA;*C.+<_;SE`,:/XA;*C.+4_;SE`,:/XA;*C.+,_;SE`,:/XA;*
MC.+$_;SE`,:/XA;*C.*\_;SE`,:/XA;*C.*T_;SE`,:/XA;*C.*L_;SE`,:/
MXA;*C.*D_;SE`,:/XA;*C.*<_;SE`,:/XA;*C.*4_;SE`,:/XA;*C.*,_;SE
M`,:/XA;*C.*$_;SE`,:/XA;*C.)\_;SE`,:/XA;*C.)T_;SE`,:/XA;*C.)L
M_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/XA;*C.)4_;SE`,:/XA;*
MC.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE`,:/XA;*C.(T_;SE`,:/
MXA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<_;SE`,:/XA;*C.(4_;SE
M`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*C.+\_+SE`,:/XA;*C.+T
M_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/XA;*C.+<_+SE`,:/XA;*
MC.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE`,:/XA;*C.*\_+SE`,:/
MXA;*C.*T_+SE`,:/XA;*C.*L_+SE`,:/XA;*C.*D_+SE`,:/XA;*C.*<_+SE
M`,:/XA;*C.*4_+SE`,:/XA;*C.*,_+SE`,:/XA;*C.*$_+SE`,:/XA;*C.)\
M_+SE`,:/XA;*C.)T_+SE`,:/XA;*C.)L_+SE`,:/XA;*C.)D_+SE`,:/XA;*
MC.)<_+SE`,:/XA;*C.)4_+SE<$`MZ2#03>(<`(WE&!"-Y10@C>48$(WB%""-
MXAP`C>+\09_EJO__Z_@QG^4$0(_@`S"4YPPPC>7L,9_E#""=Y0,PE.<"$*#A
M`P"@X1`PC>5:___KU#&?Y0,PE.<`8-/ES#&?Y0``5N,#4)3G"P``&GS__^N\
M(9_E``!0XP(@C^`0`(+E`0``&@$`H..9___KJO__ZP``E>7`___K/6?`Y0``
ME>6]___KGC/0Y0(P@^.>,\#E``"5Y;C__^N>,]#E`3"#XYXSP.4<`)WE!0"`
MX@<!<.,&``":7#&?Y5P!G^4#,)3G``"/X`,0H.$,,(WE(/__ZP`!H.&*___K
M`!"@X1C`G>4X,9_E`""<Y0,PC^``((#E+"&?Y0@`@^4"((_@!""`Y2`AG^4"
M((_@`""2Y0@@@.44(9_E`B"/X`P@H>4$(*#C!""#Y0$PH.,<()WE`P!2X2X`
M`,H`,*#C#1&"XNQ0G^4!,8#GZ!"?Y0`PC>4%4(_@`#"@X0,@@N(0`)7E`1"/
MX"7__^L`0%#B`@``&A``E>5=___K`$"@X;A0G^4%4(_@$`"5Y3W__^NL`)_E
M``"/X-X``.L``%#C#```&@PPE>4``%/C`P``&I``G^4``(_@U@``ZPP`A>6$
M,)_E`S"/X`P`D^4``%#C````"MD&`.MP,)_E`S"/X!``D^5O___KR?[_ZP0`
MH.$@T(WB<("]Z`/AG.<!,(/B!."AY<K__^H<:P$`1`$``$`!```,`0``(`$`
M`&QL`0`D`0``92L``-QK`0!U+0``H&L!`%PM``!X:P$```D``$AK`0#K*@``
M@"H```AK`0#P:@$``+"@XP#@H.,0$)_E`1"/X`T`H.$/P,#C#-"@X0```.O<
M9P$`'T`MZ4@PG^5(()_E`S"/X`(@D^<(((WE/""?Y0(@D^<,((WE`""@XP0@
MC>4L()_E`C"3YP0@@.(`,(WE`!"0Y0@PG>4,`)WE\_[_ZQ30C>($\)WDJ&@!
M`!P!```$`0``$`$``$``G^5`,)_E0""?Y0``C^`#,(_@``!3X0(@C^`>_R\!
M+#"?Y0C03>(#,)+G!#"-Y0``4^,!```*"-"-XA/_+^$(T(WB'O\OX<AI`0#$
M:0$`.&@!`!@!``!,`)_E3!"?Y0``C^`!$(_@`#!!X*,?H.$\()_E0Q&!X,$0
ML.$"((_@'O\O`2PPG^4(T$WB`S"2YP0PC>4``%/C`0``"@C0C>(3_R_A"-"-
MXA[_+^%T:0$`<&D!`-1G`0`X`0``:#"?Y1!`+>D#,(_@`##3Y5Q`G^4``%/C
M!$"/X!"`O1A0,)_E`S"4YP``4^,"```*1#"?Y0,`G^>[_O_KP/__ZS@PG^4#
M,)3G``!3XP(```HL`)_E``"/X%S^_^L!(*#C(#"?Y0,PC^``(,/E$("]Z!!I
M`0!\9P$`,`$``*AH`0`4`0``'&4``+1H`0`P,)_E,""?Y0,PC^`",)/G``!3
MXP8```H00"WI'!"?Y1P`G^4!$(_@``"/X)[^_^L00+WHM?__Z@!G`0`T`0``
M;&@!`+QD``"<,)_E\$<MZ0!04.(#,(_@!4"@`2````J(()_E`C"3YP!`D^4`
M`%3C&P``"@&0H.$%,*#A`V"@X0$0T^0``%'C/0!1$_K__QH$@*#A!6!&X`AP
MH.$$H)CD``!:XPI`H`$-```*!B"@X040H.$*`*#A1?[_ZP``4./T__\:!C#:
MYST`4^/Q__\:!$!'X$1!H.$`0(GE`4"&X@1`BN`$`*#A\(>]Z+1F`0`H`0``
M!T`MZ4@@G^5(,)_E`B"/X`,PDN<-$*#A`#"3Y00PC>4`,*#CRO__ZRP@G^4D
M,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^`````*F?[_ZPS0C>($\)WD"&8!`"P!
M``#D90$`<T`MZ8P@G^6,,)_E`B"/X`,PDN<`0*#A`#"3Y00PC>4`,*#C#6"@
MX7!0G^4%4(_@!A"@X00`H.&M___K``!0XP@``!I8()_E3#"?Y0(@C^`#,)+G
M`""3Y00PG>4"(#/@"@``"GK^_^LX,)_E`""=Y0,PE><`,)/E`C&#X`0@D^4`
M`%+C!""#Y/O__QKG___J"-"-XG"`O>BH90$`+`$``(AE`0!H90$`*`$``/!/
M+>D!4*#AR"&?Y<@QG^4"((_@`S"2YQ303>(`,)/E##"-Y0`PH.,`,-'E`&"@
MX3T`4^,!4($"!0"@X5;^_^L($(WB`'"@X08`H.%]___KB)&?Y0!`4.()D(_@
M$0``"DW^_^L'`%#A-@``.@%`1.(!,-7D``!3XP$PY.7[__\:``"@XU@AG^5,
M,9_E`B"/X`,PDN<`()/E##"=Y0(@,^!*```*/_[_ZS@QG^4#H)GG`+":Y00Q
MF^<``%/C#@``&B0QG^4"@(3B`S"/X``@D^4(@:#A``!2XPD```H($*#A"P"@
MX83]_^L``%#C``"*Y0\``!H``.#CX?__Z@%`A.+K___J`2"@XP@`H.$`((/E
MJ?W_ZP`P4.($,(WE]/__"@L0H.$(($CBIOW_ZP0PG>4`,(KE`#":Y0B`@^``
M,*#C!#`(Y0A`C>4&,*#A`P"@X0$@T^0``%+C/0!2$_K__QJ`,)_E!@!`X`-`
MF><"<(?B!P"`X`B0G>4`@)3ECOW_ZP``4.,)`8CGV?__"@`PE.4(()WE`B&3
MYP$0UN0",*#A/0!1XP``41,`$,+E`2""XOC__QH](*#C`"##Y0$@U>0``%+C
M`2#CY?O__QJK___J%-"-XO"/O>CX9`$`+`$``+!D`0!\9`$`*`$``.!E`0#P
M1RWI/"&?Y3PQG^4"((_@`S"2YW#03>(`4%#B`#"3Y6PPC>4`,*#C$P``"@`P
MU>4``%/C$```"BK]_^L`8%#B#0``"@1QG^4$@9_E!)&?Y0=PC^`(@(_@"9"/
MX`8`H.%'_?_K`$!0X@P``!H&`*#A9/W_ZP4`H.&G_?_KV""?Y<0PG^4"((_@
M`S"2YP`@D^5L,)WE`B`SX"@```K%_?_K$T"$X@<0H.$$`*#A,?W_ZP``4./H
M__\*"!"@X00`H.$L_?_K``!0X^/__PH%`*#AM?W_ZP"@H.$$`*#ALOW_ZP``
MBN`"`(#B-_W_ZP"@H.$$,*#A!2"@X0D0H.&>_?_K#1"@X0H`H.&/_?_K`0!P
MXPH`H.$'```*$#"=Y0\Z`^(!"5/C`P``&K3__^L*`*#A@OW_Z\C__^H@_?_K
M^O__ZG#0C>+PA[WH#&,!`"P!``"'(P``@B,``($C``"48@$`$$`MZ80@G^6$
M,)_E`B"/X'#03>(#,)+G#1"@X0!`H.$`,)/E;#"-Y0`PH.,:_?_K``!0XP``
MH!,)```:$#"=Y0\Z`^(*"E/C`0E3$P0``!H"$*#C!`"@X=G\_^L0#V_AH`*@
MX2P@G^4D,)_E`B"/X`,PDN<`()/E;#"=Y0(@,^`````*<_W_ZW#0C>(0@+WH
MK&$!`"P!``!,80$`$T`MZ3Q`G^4\,)_E!$"/X`,PE.<``)/E5?W_ZRPPG^4L
M$)_E`S"4YP$0C^`$,(WE(#"?Y00@G>4#,(_@"-"-XA!`O>A$_?_J$&$!`"`!
M```\`0``NR$``)1>```30"WI3#"?Y4P@G^4#,(_@`D"3YP``E.4^_?_KX/__
MZP``E.4[_?_K`""@XRPPG^4$((WE*!"?Y2@@G^4#,(_@`#"-Y0(@C^`!$(_@
MI/S_ZPC0C>(0@+WHM&`!`"`!``#,(P``6R$``/@.``#P0"WI+!&?Y2PAG^4"
MVDWB'-!-X@$0C^`"()'G`CJ-XA0P@^(`()+E`""#Y0`@H..<_/_K!"&?Y01A
MG^4"((_@`""-Y?P@G^4,<(WB`#"@X080H.$'`*#A`B"/X(+\_^L!,(#B!@!3
MX0```)KP`/#G``!0XPL``*H`,*#CR`"?Y;00G^4``(_@`BJ-X@$0D.<4((+B
M``"1Y0`0DN4``#'@(```"A+]_^L!6HWB$%"%X@$JH.,%$*#A!P"@X<'\_^L`
M0%#BZ___N@$`A.*-_/_K`#!0XN?__PH%`%/A`@``*@0@@^`"`%7AW___.@4`
M4^$"``":!""%X`(`4^':__\Z!@!4X=C__\H$(*#A`P"@X040H.'J_/_K`""@
MXP`PH.$$(,#GU/__Z@,`H.$"VHWB'-"-XO"`O>A`8`$`+`$``!PA```!$```
M]"```-!?`0"J___J\$\MZ0%0H.'L$9_E["&?Y4+=3>(!$(_@!-!-X@!`H.'<
M`9_E`B"1YT$]C>(``(_@/#"#X@`@DN4`((/E`""@XRG^_^LO$*#C`&"@X00`
MH.%X_/_K``!0XPX```JD`9_E!!"@X0``C^!B_O_KF!&?Y8@AG^4!$(_@03V-
MX@(@D><\,(/B`!"2Y0`@D^4!$#+@50``"L'\_^L$`*#AO/S_ZV@1G^4,`(WE
M`1"/X`4`H.&E_/_K`'"@X521G^54H9_E5+&?Y0F0C^`*H(_@"["/X```5^/@
M__\*`"#7Y0``4N,)<*`!``!6XPD```H'$*#A!@"@X1G\_^L``%#C!```&A@1
MG^4!$(_@C_S_ZP!PH.'N___J!P"@X9W\_^L`P*#C``"'X`<00.`!('#E+P!2
MXQ$```H,,)WE`2"#X@$@@N`!"E+CQ/__JH"`C>($4$CB!S"@X0H@H.$!&J#C
M!0"@X01`C>4`L(WEZOO_ZP$`@.(!"E#C`@``FO``\.<`P,#EY___Z@4`H.$0
M$(WB:/S_ZP``4.,0```:8#`8Y0\Z`^(""5/C#```&@$0H.,%`*#AU?O_ZP``
M4.,'```:8`"?Y040H.$``(_@"O[_ZP4`H.$)_/_K`$"@X:/__^I$$)_E``"@
MXP$0C^#&___J!`"@X4+=C>($T(WB\(^]Z.Q>`0`L`0``W!\``*T?``",7@$`
M=A\``/L>```D(```5!\``!H?``!-'@``.AX````PH.$!(-/D``!2XQ[_+P$O
M`%+C`P"@`?G__^H00"WI`$!0X@(```H`,-3E``!3XP,``!K8`)_E``"/X!!`
MO>CB^__J1_S_ZP$`0.(``(3@``!4X0`PH.$;```J`"#3Y0$`0.(O`%+C^/__
M"@`0T^4#(*#A+P!1XP$P0^(0```:`C"@X0$P0^(#`%3A`R"@X0,``"H`$-+E
M`3!#XB\`4>/X__\*!"!"X`(P@N(!"E/C%0``B@$@@N(!"E+C#```FO``\.<#
M`%3AY___.@,`5.'K__\:`##4Y2\`4^,T`)\%``"/`-3__PHL`)_E``"/X-'_
M_^HD,)_E!!"@X0,PC^`#`*#ATOO_ZQ"`O>@``*#C$("]Z%L=``"S'```"!T`
M`(Q=`0`00"WIP"&?Y<`QG^4"((_@*-!-X@,PDN<-(*#AL!&?Y0`PD^4D,(WE
M`#"@XP$0C^`*,('B*L"!X@+@H.$``)/E!!"3Y0@P@^(#`*[H#`!3X0X@H.'W
M__\:L##3X70!G^6P,,[A``"/X&/]_^MH`9_E:$&?Y0``C^!?_?_K8`&?Y01`
MC^```(_@6_W_ZU0!G^4``(_@6/W_ZTP!G^4``(_@5?W_ZT0!G^4``(_@4OW_
MZSP!G^4``(_@3_W_ZS0!G^4``(_@3/W_ZP0`H.%*_?_K)`&?Y0``C^!'_?_K
M'`&?Y0``C^!$_?_K%`&?Y0``C^`I_?_K`!!0X@$```H$`*#A:/W_Z_P`G^4`
M`(_@(OW_ZP`04.("```*[`"?Y0``C^!@_?_KY`"?Y0``C^`:_?_K`!!0XA``
M``K4`)_E``"/X%C]_^O,$)_ES`"?Y0$0C^```(_@4_W_Z\`@G^5L,)_E`B"/
MX`,PDN<`()/E)#"=Y0(@,^`2```*M/O_ZZ``G^4``(_@!/W_ZP`04.*4`)\5
M``"/$.G__QJ,$)_E"B"@XP$0C^`1`(WB,_O_ZP``4./C__\:=`"?Y1L0C>(`
M`(_@WO__ZBC0C>(0@+WHI%L!`"P!```T60``;AP``&<<``"9'```7QP``%P<
M``!7'```6QP```0<``!/'```3QP``.$;``!!'```-AP``"T;```H'```?!L`
M`#`<``"C&P``4%H!`.`;``!_&P``T1L``%,;```00"WI3#"?Y0,PC^``,)/E
M`0!SXPP``!H\`)_E``"/X-#\_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,`
M`*`#&#"?Y0,PC^```(/E$#"?Y0,`G^<0@+WHP%H!`+\:``"$6@$`>%H!`!!`
M+>EM^__K%?O_ZP``4.,``)`5$("]Z/=`+>F8<)_E`$"@X0=PC^`'`*#AL_S_
MZP!04.($$*#A`@``"@`PU>4``%/C!```&G``G^4``(_@#-"-XO!`O>CK_/_J
M\?K_ZP``4.,2```:!`"@X4W[_^L`8*#A!0"@X4K[_^L``(;@`@"`XL_Z_^L`
M8*#A,#"?Y3`0G^4$(*#A`1"/X`!0C>4#,(_@,_O_ZP80H.$'`*#AYO__Z@S0
MC>+P@+WHOAH``)8:``"2&0``:!H``/!/+>D\%I_E/":?Y0+93>+TT$WB`1"/
MX##&G^4"()'G`CF-XO!`C>(,P(_@`""2Y>P@@^4`(*#C[#"#XA!0C.)T,$3B
M7.!$X@!@H.$'`)SI!P"#Z`\`M>@/`*[H`P"5Z&@P1.(HP(SB`P".Z`<`G.@'
M`(/HV`6?Y=AUG^4``(_@:_S_ZP!04.('<(_@$0``"@`PU>4``%/C#@``"JK_
M_^L%`*#AIOK_ZP!0H.&H%9_EE"6?Y0$0C^`".8WB`B"1Y^PP@^(`$)+E`""3
MY0$0,N!8`0`*`_O_ZY7__^L`4%#B:(!$`E@```H%`*#A^OK_ZX``H.$!`(#B
M?_K_ZP"0H.$`@*#A5*6?Y0%01>(*H(_@`2#UY0``4N-1```:7(!$X@10F.0`
M`%7C#```"@4`H.$__/_K`%!0XOC__PH`,-7E``!3X_7__PI0_?_K``!0X_+_
M_PH%`*#A>?K_ZP!0H.%TH$3B``!5XP4``!H$@)KD``!8XT<```H`,-CE``!3
MXSP``!H%`*#AT_K_ZP"@H.$)`*#AT/K_ZP``BN`!JX#B!*"*X@H`H.%3^O_K
M`("@X:PTG^6L%)_E`S"/X``PC>6D-)_E!2"@X0,PC^`!$(_@!)"-Y;3Z_^L'
M':#C"`"@X9_Z_^L!`'#C+```&IGZ_^L`,)#E$0!3XR@```IL))_E;!2?Y0(`
ME^<`,(WE`""6Y0@PH.$``)#E`1"/X'CZ_^L`4*#CH/__Z@'\_^L`,%#B!0``
M"@`PT^4``%/C`@``"C_Z_^L`4%#BIO__&@0`F.0``%#C\___&AA4G^4%4(_@
MH/__Z@@`H.$*$*#ACOK_ZP*`B.*E___J"`"@X0/]_^L``%#CN/__"@@`H.$L
M^O_K`%"@X;+__^H(4*#AN/__Z@@`H.'@$$3B'_K_ZP"04.((```*M#.?Y;P3
MG^4#`)?G`""6Y0@PH.$!$(_@``"0Y4OZ_^O1___JT#`4Y0\Z`^(!"5/C\O__
M&LA0%.6`^O_K``!5X>[__QK0,!3E@SN@X:,[H.$'#5/CZ?__&@H`H.'Y^?_K
M`%"@X6`#G^4``(_@P_O_ZP``4.-A```:`'"6Y0<`H.%H^O_K`P!0XP"@H.$:
M``":.!.?Y00`0.(!$(_@``"'X-/Y_^L``%#C$P``&@0`6N,#```*"J"'X`4P
M6N4O`%/C#0``&@1@EN4``%;C"@``"@8`H.%3^O_K`P!0XP8``)KL$I_E!`!`
MX@$0C^```(;@O_G_ZP``4.,&<*`!Q?[_ZP"@4.)U```:"A"@X0<`H.'A^?_K
M`&!0XG````H"D*#C`##@XQ$@X.,`D(WE!'!$XJGY_^L&(*#C!Q"@X08`H.$.
M^O_K!#!4Y0``4^,S```:`S!4Y4,`4^,P```:`C!4Y4$`4^,M```:`3!4Y4,`
M4^,J```:`##4Y4@`4^,G```:`3#4Y44`4^,D```:`##@XSD@X.,&`*#A`)"-
MY8[Y_^LI(*#C!Q"@X08`H.'S^?_K"""@X1PRG^4<$I_E`S"/X`0PC>44,I_E
M`'"-Y0,PC^`!$(_@!0"@X0;Z_^L(`*#A]?G_Z_@!G^4%$*#A``"/X*7[_^L%
M`*#AIO[_Z_W^_^H`<);EH?G_ZP`0H.$'`*#A'_W_ZP!P4.*7__\:E?__Z@`P
MH.,`(*#C`#"-Y08`H.$`,*#C:/G_ZT8$`.L`D*#A`BF@XP<0H.$&`*#AR_G_
MZP`@4.(=``#*!@"@X41@1.+`^?_K,'!$X@D0H.$&`*#AG00`ZP>0H.%HL9_E
M"["/X`<`H.$+$*#A`2#6Y`&@BN+8^?_K%`!:XP)PA^+W__\:`#"@XP@P1.4\
M,9_E/!&?Y0,PC^`$,(WE-#&?Y0@@H.$`D(WE`S"/X`$0C^#`___J!Q"@X0D`
MH.$R!`#KU___ZA`1G^40`9_E`1"/X```C^!E^__K._G_ZP`QG^4`$9_E`S"/
MX`D`C>CX,)_E"""@X04`H.$#,(_@`1"/X+7Y_^OD0)_EY&"?Y>1PG^4$0(_@
M!F"/X`=PC^`'':#C!0"@X9KY_^L!`'#CH___&I3Y_^L`,)#E$0!3XY___QHA
M^?_K`9")X@$"C>@$,*#A"""@X080H.$%`*#A"'"-Y9WY_^OL___J!0"@X0+9
MC>+TT(WB\(^]Z#18`0`L`0``;%D!`-08``#`5P$`E%<!`"$9``"#&```9A@`
M`*`7```(`0``*!@``,H7``"S%P``!1<``((7```W%P``(!<``%06``#H%```
ML!0``/T4```L%@``7!4``/`3``!X%```!Q0``-P5```;%0``H!,``(@3```1
M%0``J!4``/=/+>DX,Y_E.".?Y0,PC^`"0)/G``"4Y6WY_^L`4*#A``"4Y6KY
M_^MD,-7E93#`Y10#G^4``(_@ROK_ZP``4.,%```*`##0Y3$`4^,"```:`3#0
MY0``4^,````*6OW_ZP``E.5:^?_KX!*?Y0LPH.,!(*#C`1"/X`KY_^L``%#C
M'@``&@``E.51^?_KP!*?Y0,PH.,!(*#C`1"/X`'Y_^L`4%#B3@``&@``E.5(
M^?_KH!*?Y0,PH.,!(*#C`1"/X/CX_^L`4%#B8@``"H@"G^4``(_@H_K_ZP`@
M4.($((WE40``"@``E.4Y^?_K##"5Y00@G>4`$)/E\/C_ZU4``.H!4*#C##"0
MY5"2G^48<)/E3**?Y0F0C^`$,)GE``"4Y04`4^$!@$7B!@``VBCY_^L`,*#C
M"""@X0<0H.&O^/_K`&!0X@@``!H8,I_E`S"/X`0@D^4!($+B`@!8X<C__QH!
M8*#C`U"@X1@``.H(,)GE`""6Y06QD^<(,)+E"C`#X`$+4^,,$)(%!@``"@``
ME.4/^?_K`!"6Y0(PH.,`(*#C%_G_ZP`0H.$+`*#ABOC_ZP``4./C__\:`5"%
MXM7__^H#^?_K!Q"@X6+X_^L!8(;B!#"5Y0``E.4&`%/A]___RJ?__^H``)3E
M^?C_ZPPPE>5T(9_E`!"3Y0(@C^"O^/_K##"5Y0`PD^4(,)/E`043XZ3__PH`
M`)3E[?C_ZPPPE>4`$)/E>_C_ZY[__^J]^__K`&!0X@``E.4H```*Y/C_ZPPP
ME>4&(*#A`!"3Y9OX_^L&`*#ATOC_ZP``E.7<^/_K`%"@X0``E.79^/_K_!"?
MY0$@H.,!$(_@/_C_Z_`@G^4`$*#A`B"/X`4`H.&+^/_K``"4Y<[X_^L`,*#C
M93#`Y=``G^700)_E``"/X"WZ_^L$0(_@``!0XPP`A.4.```:"`"4Y9K]_^L`
M`%#C#`"$Y0D``!JD`)_E``"/X#+X_^N[^/_KF#"?Y0,PC^`(()/E##"5Y0`@
MDN5]___JA$"?Y0<=H.,$0(_@#`"4Y:'X_^L!,(#B$0!0XP$`4Q,&``":`#"@
MX0@0E.5<`)_E#""4Y0`0D>4``(_@&_C_ZPS0C>+PC[WH<%$!`"`!``"+$@``
MQA,``*<3``"*$P``O1$```A2`0``!"``T%$!`$D2``#4$0``V1$``-P/``!L
M4`$`BQ$``#10`0`84`$`4!$``'!`+>D`0*#A2?S_ZT'\_^L`4*#A%?W_ZP``
M4.,``%03<("]"``PU.4``%/C<("]"!P0G^4%`*#A`1"/X"_X_^L``%7A<("]
M&`0`H.%P0+WHG_K_ZJ</``#P3RWI,"N?Y3`[G^4"((_@4]]-X@,PDN<$((WB
M`L"@X0`PD^5$,8WE`#"@XUS@@.(<,(#B!!"3Y#$?O^8#`%[A!!",Y/K__QI`
MP*#C`A"@X2#@D>4T,)'E!"""X@XP(^`(X)'E`!"1Y0XP(^`!,"/@XS^@X0'`
M7.(\,(+E\O__&KPJG^4$D)WE`("0Y0@PG>740,#AW&#`X601)>`&P"7@`I")
MX`>0B>`$P`S@"!`!X`(P@^`&P"S@!C"#X.B=B>`%$"'@#)")X`,0@>!HP:#A
M##"=Y62A+.`)H`K@`C"#X`4P@^`0X)WE9*$JX.D=@>`#H(K@:3$LX`$P`^`"
MX([@X:V*X&3ACN!A$:#A%+"=Y0PP(^`.,(/@:>$AX`*PB^`*X`[@#,"+X&GA
M+N`8L)WEZCV#X`S@CN!JP2'@`K"+X`/`#.#C[8[@:9&+X&,QH.$<L)WE`<`L
MX`G`C.!JD2/@`K"+X`Z0">`!$(O@:I$IX""PG>7NS8S@`9")X&X1(^`"L(O@
M#!`!X.R=B>!JH8O@;,&@X22PG>4#$"'@"A"!X&ZA+.`"L(O@":`*X`,PB^!N
MH2K@*+"=Y>D=@>`#H(K@:3$LX`*PB^`!,`/@X:V*X&[AB^!A$:#A++"=Y0PP
M(^`.,(/@:>$AX`*PB^`*X`[@#,"+X&GA+N`PL)WEZCV#X`S@CN!JP2'@`K"+
MX`/`#.!ID8O@`<`LX./MCN`)P(S@8S&@X320G>5JL2/@`I")X`ZP"^`!$(G@
M:K$KX#B0G>7NS8S@`;"+X&X1(^`"D(G@#!`!X.R]B^!JH8G@;,&@X3R0G>4#
M$"'@"A"!X&ZA+.`"D(G@"Z`*X`,PB>!NH2K@0)"=Y>L=@>`#H(K@:S$LX`*0
MB>`!,`/@X:V*X&[AB>!A$:#A1)"=Y0PP(^`.,(/@:^$AX`*0B>`*X`[@:^$N
MX`S`B>`,P([@2."=Y>H]@^!JD2'@`N".X`.0">!KL8[@`9`IX./-C.`+D(G@
M8S&@X4RPG>5JX2/@`K"+X`S@#N!JX2[@`1"+X%"PG>7LG8G@`1".X&SA(^`"
M((O@">`.X&JA@N`#X"[@&"B?Y0K@CN!4H)WEZ1V!X`*@BN!ID:#A`S"*X&RA
M*>`!H"K@"J"#X%@PG>7A[8[@`C"#X&S!@^!A,2G@#C`CX`/`C.!<,)WE[JV*
MX`(P@^!NX:#A"9"#X&$Q+N`*,"/@`Y")X&`PG>7JS8S@`C"#X&$Q@^!J$2[@
M#!`AX`$P@^!D$)WE[)V)X`(0@>!LP:#A#N"!X&H1+.`)$"'@`>".X&@0G>5L
ML)WE`A"!X.D]@^!J$8'@::$LX./MCN`#H"K@`K"+X&,QH.$,P(O@:;$CX`ZP
M*^`+L(S@<,"=Y0H0@>`"P(S@[AV!X&G!C.!ND2/@`9`IX`G`C.!TD)WEX;V+
MX`*0B>!A$:#A`S")X&Z1(>`+D"G@"9"#X'@PG>5\H)WE`C"#X.O-C.!N,8/@
M:^$AX.R=B>`,X"[@`J"*X&S!H.$!$(K@:Z$LX`F@*N`*H('@@!"=Y0XP@^`"
M$('@A."=Y>D]@^!K$8'@:;$LX..MBN`#L"O@`N".X&,QH.$,P([@:>$CX`K@
M+N`.X(S@B,"=Y0L0@>`"P(S@C+"=Y>H=@>!IP8S@:I$CX.'MCN`!D"G@`K"+
MX&$1H.$#,(O@:K$AX`ZP*^`+L(/@D#"=Y0G`C.`",(/@[LV,X&HQ@^!NH2'@
M#*`JX`HP@^"4H)WE[+V+X`*@BN!LP:#A`1"*X&ZA+.`+H"K@"J"!X)@0G>6<
MD)WE`A"!X.L]@^!N$8'@:^$LX..MBN`#X"[@`I")X&,QH.$,D(G@:\$CX`K`
M+.`,D(G@H,"=Y0X0@>`"P(S@ZAV!X&O!C.!JL2/@X9V)X`&P*^!A$:#A:N&!
MX6HA`>`)X`[@"\",X`+@CN&DL)WEH"6?Y>G-C.`"L(O@`S"+X`/@CN!I,8'A
M:;$!X`PP`^`+,(/AJ+"=Y>SMCN`"L(O@;,&@X6JAB^!IL8SA"C"#X`ZP"^!I
MH0S@"K"+X:R@G>7N/8/@`J"*X`$0BN`!L(O@;A&,X6ZA#.`#$`'@"A"!X;"@
MG>7CO8O@`J"*X&,QH.%ID8K@"1"!X&Z1@^%NH0/@"Y`)X`J0B>&TH)WEZQV!
MX`*@BN`,P(K@#)")X&O!@^%KH0/@`<`,X`K`C.&XH)WEX9V)X`*@BN!A$:#A
M;N&*X&NA@>$.P(S@":`*X&OA`>`.H(KAO."=Y>G-C.`"X([@`S".X`.@BN!I
M,8'A:>$!X`PP`^`.,(/AP."=Y>RMBN`"X([@;,&@X6NQCN`+,(/@:;&,X6GA
M#.`*L`O@#K"+X<3@G>7J/8/@`N".X`$0CN`!L(O@:A&,X6KA#.`#$`'@#A"!
MX<C@G>7CO8O@`N".X&,QH.%ID8[@"1"!X&J1@^%JX0/@"Y`)X`Z0B>',X)WE
MZQV!X`+@CN`,P([@:^&#X0R0B>`!X`[@:\$#X`S@CN'0P)WEX9V)X`+`C.!A
M$:#A:J&,X&O!@>$*X([@"<`,X&NA`>`*P(SAU*"=Y>GMCN`"H(K@`S"*X`,P
MC.!IP8'A::$!X`[`#.`*P(SAV*"=Y>X]@^`"H(K@;N&@X6NQBN`+P(S@:;&.
MX6FA#N`#L`O@"K"+X=R@G>7CS8S@`J"*X`$0BN`!L(O@8Q&.X6.A#N`,$`'@
M"A"!X>"@G>7LO8O@`J"*X&S!H.%ID8K@"1"!X&.1C.%CH0S@"Y`)X`J0B>'D
MH)WEZQV!X`*@BN`.X(K@:Z&,X0[@B>`!H`K@:Y$,X`F@BN'HD)WEX>V.X`*0
MB>!A$:#A8S&)X`.@BN!K,8'A:Y$!X`XP`^`),(/A[)"=Y>ZMBN`"D(G@#,")
MX&Z1@>$,P(/@"I`)X&XQ`>`#D(GA\#"=Y>K-C.`"((/@:[&"X,0RG^7T()WE
M:J&@X0,@@N`!$(+@;B$JX`P@(N`"$('@^""=Y0N0B>`#((+@[)V)X&[A@N!L
M(2K@"2`BX`+@CN#\()WEZ1V!X`,@@N!ID:#A"J""X&PA*>`!("+@`J"*X``A
MG>7A[8[@`R""X&PA@N!AP2G@#L`LX`P@@N`$P9WE[JV*X`/`C.!NX:#A"9",
MX&'!+N`*P"S@#)")X`C!G>7J+8+@`\",X&'!C.!J$2[@`A`AX`'`C.`,$9WE
MXIV)X`,0@>!B(:#A#N"!X&H1(N`)$"'@`>".X!`1G>44L9WE`Q"!X.G-C.!J
M$8'@::$BX.SMCN`,H"K@`["+X&S!H.$"((O@:;$LX`ZP*^`+L(+@&"&=Y0H0
M@>`#((+@[AV!X&DA@N!ND2S@`9`IX`D@@N`<D9WEX;V+X`.0B>!A$:#A#,")
MX&Z1(>`+D"G@"9",X"#!G>4DH9WE`\",X.LM@N!NP8S@:^$AX.*=B>`"X"[@
M`Z"*X&(AH.$!$(K@:Z$BX`F@*N`*H('@*!&=Y0[`C.`#$('@+.&=Y>G-C.!K
M$8'@:;$BX.RMBN`#X([@#+`KX&S!H.$"(([@:>$LX`K@+N`.X(+@,"&=Y0L0
M@>`#((+@ZAV!X&DA@N!JD2S@`9`IX`D@@N`TD9WEX>V.X`.0B>!A$:#A#,")
MX&J1(>`.D"G@"<",X#B1G>7N+8+@`Y")X&JAB>!ND2'@`I`IX`F@BN`\D9WE
MXLV,X`.0B>!B(:#A`1")X&Z1(N`,D"G@"1"!X$"1G>7LK8K@`S")X`B`@^!N
MX8C@;($BX`J`*.#J'8'@`G"'X`C@CN!@()_E2#"?Y>'MCN`!0(3@:E&%X&QA
MAN`"((_@`."`Y01`@.4(4(#E#&"`Y1!P@.4#,)+G`""3Y40QG>4"(#/@````
M"K_U_^M3WXWB\(^]Z(A-`0`L`0``F7F"6J'KV6[<O!N/UL%BRI!"`0`00"WI
M8`"@XSCU_^LH$)_E*""?Y2C`G^4HX)_E!E"`Z"0@G^40((#E`""@XQ0@@.48
M((#E7""`Y1"`O>@!(T5GB:O-[_[<NIAV5#(0\.'2P_!!+>D"8*#A`%"@X10P
MD.6"(:#A`C"3X!@@D"44,(#E`2""(A@@@"48,)#E''"%XJ8^@^`8,(#E7`"0
MY0``4.,9```*0$!@X@0`5N$``(?@!D"@L0$`4.$#```J!#"`X`,`4>$````J
M\`#PYP$`4.$$@('@`0``F@@`4.'Y__\Z!""@X73U_^M<,)7E`S"$X$``4^-<
M,(7E\(&]&`4`H.'L_/_K"!"@X01@1N!<@(7B/P!6XPX``,H'`%'A`@``F@8P
MA^`#`%'AYO__.@<`4>$"```J!C"!X`,`5^'A__\Z!B"@X0<`H.%;]?_K7&"%
MY?"!O>@'`%'A`0``F@@`4>'8__\Z!P!1X4`P@>(!```J`P!7X=/__SH!0*#A
M!R"@X000E.0#`%3A!!""Y/O__QH%`*#AQ_S_ZT!@1N($$*#AVO__ZO!!+>D<
M@('B%#"1Y1A@D>4!0*#A?Q#@XS-_O^:C,:#A/S`#X@$@@^(X`%+C`%"@X0,0
MR.<"`(C@`!"@TS9OO^8X(&+2!P``V@`0H.-`(&+BN/3_ZP0`H.&M_/_K.""@
MXP`0H.,(`*#ALO3_ZP0`H.'T9<3AIOS_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E
M`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,TH.$&
M,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4Y0LP
MQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E$##%
MY;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P0;WHY?3_Z@%`+>D!0+WH
M'O\OX2]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!54T52`%5315).04U%
M`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!E>&4`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`"5S)7,E<R5S`'!A<BT`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`T.0!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL
M96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D
M8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*
M8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M
M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ
M92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@
M)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M
M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*
M?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?
M<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M
M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S
M(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").
M(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER
M95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E"
M.B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D
M9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I
M;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E
M($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M*&UY("1F:"P@(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X
M9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)
M0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D
M<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@
M)&9H+"`B/"(L("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@+R\@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I
M9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL
M92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY
M("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M
M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',[
M"F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"H%P``'!<```$````!`````0```.@"```/````
MC@0```P```!@$```#0```$`_```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```"L!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<```!P#@``$0``
M`(`-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0
M``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!``
M`&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```
M;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L
M$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0
M``!L$```;!```&P0``!L$```;!```&P0``!L$```:!,`````````````0#\`
M````````````8!``````````````````````````````````````````````
M````````````@`$`_____TP_``!W/P```````%$_``!10```7#\``&-```!D
M/P```````&@_``!M/P````````="``!'0T,Z("A!;'!I;F4@."XS+C`I(#@N
M,RXP`$=#0SH@*$%L<&EN92`Y+C(N,"D@.2XR+C``03(```!A96%B:0`!*```
M``4V6DL`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@0B`40!`"YS:'-T<G1A
M8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N
M8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````
M````````````````````````````````"P````$````"````%`$``!0!```8
M```````````````!`````````!,```#V__]O`@```"P!```L`0``Z`````,`
M````````!`````0````=````"P````(````4`@``%`(``,`&```$`````P``
M``0````0````)0````,````"````U`@``-0(``"L!``````````````!````
M`````"T````)`````@```(`-``"`#0``\`````,`````````!`````@````V
M````"0```$(```!P#@``<`X``/`!```#````$`````0````(````/P````$`
M```&````8!```&`0```,```````````````$`````````#H````!````!@``
M`&P0``!L$```_`(`````````````!`````0```!%`````0````8```!H$P``
M:!,``-@K``````````````0`````````2P````$````&````0#\``$`_```,
M```````````````$`````````%$````!`````@```$P_``!,/P``2#T`````
M`````````0````````!9`````0````(```"4?```E'P```0`````````````
M``0`````````8P````X````#````P'T!`,!]```$```````````````$````
M!````&\````/`````P```,1]`0#$?0``!```````````````!`````0```![
M````!@````,```#(?0$`R'T``/`````$``````````0````(````A`````$`
M```#````N'X!`+A^``!(`0`````````````$````!````(D````!`````P``
M``"``0``@```/```````````````!`````````"/````"`````,````\@`$`
M/(```#`0``````````````0`````````E`````$````P`````````#R````T
M```````````````!`````0```)T````#``!P``````````!P@```,P``````
M`````````0`````````!`````P``````````````HX```*T`````````````
)``$`````````
